==> bearminimum-fabric-1.21.4-1.0.1-sources.jar: com/startraveler/bearminimum/entity/BrownBearEntity.java <==
package com.startraveler.bearminimum.entity;

import com.startraveler.bearminimum.Constants;
import com.startraveler.bearminimum.entity.goal.*;
import net.minecraft.class_1296;
import net.minecraft.class_1299;
import net.minecraft.class_1301;
import net.minecraft.class_1308;
import net.minecraft.class_1338;
import net.minecraft.class_1341;
import net.minecraft.class_1347;
import net.minecraft.class_1353;
import net.minecraft.class_1361;
import net.minecraft.class_1374;
import net.minecraft.class_1376;
import net.minecraft.class_1379;
import net.minecraft.class_1391;
import net.minecraft.class_1400;
import net.minecraft.class_1429;
import net.minecraft.class_1646;
import net.minecraft.class_1657;
import net.minecraft.class_1937;
import net.minecraft.class_1959;
import net.minecraft.class_3218;
import net.minecraft.class_3730;
import net.minecraft.class_5132;
import net.minecraft.class_5134;
import net.minecraft.class_5398;
import net.minecraft.class_6862;
import net.minecraft.class_7430;
import net.minecraft.class_7924;
import net.minecraft.class_8103;
import net.minecraft.world.entity.*;
import net.minecraft.world.entity.ai.goal.*;


public class BrownBearEntity extends AbstractBearEntity {

    public static final class_6862<class_1959> HAS_BROWN_BEAR_SPAWNS = class_6862.method_40092(class_7924.field_41236, Constants.id("has_brown_bear_spawns"));

    public static final float PERSONAL_SPACE_DISTANCE = 4.0f;
    // Set up proper tags!
    public static final BearFoodPreferences BROWN_BEAR_FOODS = new BearFoodPreferences(
            BearFoodPreferences.BROWN_BEAR_FOOD,
            BearFoodPreferences.BROWN_BEAR_PREY,
            BearFoodPreferences.BROWN_BEAR_FORAGE
    );

    public BrownBearEntity(class_1299<? extends BrownBearEntity> entityType, class_1937 level) {
        super(entityType, level, BROWN_BEAR_FOODS);
    }

    public static class_5132.class_5133 method_26891() {
        return class_1429.method_61457()
                .method_26868(class_5134.field_23716, 50.0F)
                .method_26868(class_5134.field_23717, 30.0F)
                .method_26868(class_5134.field_23719, 0.25F)
                .method_26868(class_5134.field_23721, 6.0F)
                .method_26868(class_5134.field_23724, 4.0F)
                .method_26868(class_5134.field_23718, 0.25F)
                .method_26868(class_5134.field_47760, 1.0);
    }

    public class_1296 method_5613(class_3218 level, class_1296 parent) {
        return (class_1296) this.method_5864().method_5883(level, class_3730.field_16466);
    }

    protected void method_5959() {
        super.method_5959();
        this.field_6201.method_6277(0, new class_1347(this));
        this.field_6201.method_6277(1, new AbstractBearMeleeAttackGoal(this));
        this.field_6201.method_6277(
                1, new class_1374(
                        this,
                        SCARED_BOOST,
                        (bear) -> bear.method_6109() ? class_8103.field_51990 : class_8103.field_51991
                )
        );
        this.field_6201.method_6277(
                2, new class_1338<>(
                        this,
                        class_1657.class,
                        (entity) -> entity.method_6115() && entity.method_6030().method_7909() instanceof class_7430,
                        PERSONAL_SPACE_DISTANCE * 3,
                        SCARED_BOOST,
                        SCARED_BOOST,
                        entity -> true
                )
        );
        this.field_6201.method_6277(2, new class_1341(this, 0.8));
        this.field_6201.method_6277(
                3,
                new class_1391(this, 0.5F, (stack) -> stack.method_31573(this.foodPreferences.foodTag()), true)
        );
        this.field_6201.method_6277(
                8, new class_1338<>(
                        this,
                        class_1657.class,
                        (entity) -> !this.method_29511(),
                        PERSONAL_SPACE_DISTANCE * 2,
                        SCARED_BOOST,
                        SCARED_BOOST,
                        class_1301.field_6156::test
                )
        );

        this.field_6201.method_6277(
                8, new class_1338<>(
                        this,
                        class_1646.class,
                        (entity) -> !this.method_29511(),
                        PERSONAL_SPACE_DISTANCE * 2,
                        SCARED_BOOST,
                        SCARED_BOOST,
                        class_1301.field_6156::test
                )
        );
        this.field_6201.method_6277(4, new class_1353(this, 1.25F));
        this.field_6201.method_6277(5, new class_1379(this, 1.0F));
        this.field_6201.method_6277(6, new ForageGoal(this));
        this.field_6201.method_6277(6, new class_1361(this, class_1657.class, PERSONAL_SPACE_DISTANCE * 3));
        this.field_6201.method_6277(7, new class_1376(this));
        this.field_6185.method_6277(1, new AbstractBearHurtByTargetGoal(this));
        this.field_6185.method_6277(2, new AbstractBearAttackPlayersGoal(this));
        this.field_6185.method_6277(
                3,
                new class_1400<>(this, class_1657.class, 10, true, false, this::method_29515)
        );

        this.field_6185.method_6277(
                4, new class_1400<>(
                        this,
                        class_1308.class,
                        10,
                        true,
                        true,
                        (entity, level) -> this.wantsMoreFood() && entity.method_5864().method_20210(this.foodPreferences.preyTag())
                )
        );
        this.field_6185.method_6277(5, new class_5398<>(this, false));
        this.field_6185.method_6277(
                7,
                new PersonalSpaceTargetGoal<>(
                        this,
                        class_1657.class,
                        PERSONAL_SPACE_DISTANCE,
                        10,
                        true,
                        true,
                        (entity, level) -> true
                )
        );
    }

}

==> bearminimum-fabric-1.21.4-1.0.2-sources.jar: com/startraveler/bearminimum/entity/BrownBearEntity.java <==
package com.startraveler.bearminimum.entity;

import com.startraveler.bearminimum.Constants;
import com.startraveler.bearminimum.entity.goal.*;
import net.minecraft.class_1296;
import net.minecraft.class_1299;
import net.minecraft.class_1301;
import net.minecraft.class_1308;
import net.minecraft.class_1338;
import net.minecraft.class_1341;
import net.minecraft.class_1347;
import net.minecraft.class_1353;
import net.minecraft.class_1361;
import net.minecraft.class_1374;
import net.minecraft.class_1376;
import net.minecraft.class_1379;
import net.minecraft.class_1391;
import net.minecraft.class_1400;
import net.minecraft.class_1429;
import net.minecraft.class_1646;
import net.minecraft.class_1657;
import net.minecraft.class_1937;
import net.minecraft.class_1959;
import net.minecraft.class_3218;
import net.minecraft.class_3730;
import net.minecraft.class_5132;
import net.minecraft.class_5134;
import net.minecraft.class_5398;
import net.minecraft.class_6862;
import net.minecraft.class_7430;
import net.minecraft.class_7924;
import net.minecraft.class_8103;
import net.minecraft.world.entity.*;
import net.minecraft.world.entity.ai.goal.*;


public class BrownBearEntity extends AbstractBearEntity {

    public static final class_6862<class_1959> HAS_BROWN_BEAR_SPAWNS = class_6862.method_40092(
            class_7924.field_41236,
            Constants.id("has_brown_bear_spawns")
    );

    public static final float PERSONAL_SPACE_DISTANCE = 4.0f;
    // Set up proper tags!
    public static final BearFoodPreferences BROWN_BEAR_FOODS = new BearFoodPreferences(
            BearFoodPreferences.BROWN_BEAR_FOOD,
            BearFoodPreferences.BROWN_BEAR_PREY,
            BearFoodPreferences.BROWN_BEAR_FORAGE
    );

    public BrownBearEntity(class_1299<? extends BrownBearEntity> entityType, class_1937 level) {
        super(entityType, level);
    }

    public static class_5132.class_5133 method_26891() {
        return class_1429.method_61457()
                .method_26868(class_5134.field_23716, 50.0F)
                .method_26868(class_5134.field_23717, 30.0F)
                .method_26868(class_5134.field_23719, 0.25F)
                .method_26868(class_5134.field_23721, 6.0F)
                .method_26868(class_5134.field_23724, 4.0F)
                .method_26868(class_5134.field_23718, 0.25F)
                .method_26868(class_5134.field_47760, 1.0);
    }

    public class_1296 method_5613(class_3218 level, class_1296 parent) {
        return (class_1296) this.method_5864().method_5883(level, class_3730.field_16466);
    }

    protected void method_5959() {
        super.method_5959();
        this.field_6201.method_6277(0, new class_1347(this));
        this.field_6201.method_6277(1, new AbstractBearMeleeAttackGoal(this));
        this.field_6201.method_6277(
                1, new class_1374(
                        this,
                        SCARED_BOOST,
                        (bear) -> bear.method_6109() ? class_8103.field_51990 : class_8103.field_51991
                )
        );
        this.field_6201.method_6277(
                2, new class_1338<>(
                        this,
                        class_1657.class,
                        (entity) -> entity.method_6115() && entity.method_6030().method_7909() instanceof class_7430,
                        PERSONAL_SPACE_DISTANCE * 3,
                        SCARED_BOOST,
                        SCARED_BOOST,
                        entity -> true
                )
        );
        this.field_6201.method_6277(2, new class_1341(this, 0.8));
        this.field_6201.method_6277(
                3,
                new class_1391(this, 0.5F, (stack) -> stack.method_31573(this.getFoodPreferences().foodTag()), true)
        );
        this.field_6201.method_6277(
                8, new class_1338<>(
                        this,
                        class_1657.class,
                        (entity) -> !this.method_29511(),
                        PERSONAL_SPACE_DISTANCE * 2,
                        SCARED_BOOST,
                        SCARED_BOOST,
                        class_1301.field_6156::test
                )
        );

        this.field_6201.method_6277(
                8, new class_1338<>(
                        this,
                        class_1646.class,
                        (entity) -> !this.method_29511(),
                        PERSONAL_SPACE_DISTANCE * 2,
                        SCARED_BOOST,
                        SCARED_BOOST,
                        class_1301.field_6156::test
                )
        );
        this.field_6201.method_6277(4, new class_1353(this, 1.25F));
        this.field_6201.method_6277(5, new class_1379(this, 1.0F));
        this.field_6201.method_6277(6, new ForageGoal(this));
        this.field_6201.method_6277(6, new class_1361(this, class_1657.class, PERSONAL_SPACE_DISTANCE * 3));
        this.field_6201.method_6277(7, new class_1376(this));
        this.field_6185.method_6277(1, new AbstractBearHurtByTargetGoal(this));
        this.field_6185.method_6277(2, new AbstractBearAttackPlayersGoal(this));
        this.field_6185.method_6277(
                3,
                new class_1400<>(this, class_1657.class, 10, true, false, this::method_29515)
        );

        this.field_6185.method_6277(
                4, new class_1400<>(
                        this,
                        class_1308.class,
                        10,
                        true,
                        true,
                        (entity, level) -> this.wantsMoreFood() && entity.method_5864().method_20210(this.getFoodPreferences().preyTag())
                )
        );
        this.field_6185.method_6277(5, new class_5398<>(this, false));
        this.field_6185.method_6277(
                7,
                new PersonalSpaceTargetGoal<>(
                        this,
                        class_1657.class,
                        PERSONAL_SPACE_DISTANCE,
                        10,
                        true,
                        true,
                        (entity, level) -> true
                )
        );
    }

    @Override
    public BearFoodPreferences getFoodPreferences() {
        return BROWN_BEAR_FOODS;
    }
}
